@@ -7,7 +7,7 @@ no warnings 'once';
 
 use Module::Install::Base;
 use base 'Module::Install::Base';
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 use FindBin;
 use File::Glob     ();
@@ -52,7 +52,7 @@ sub RTx {
         my @look = @INC;
         unshift @look, grep {defined and -d $_} @try;
         push @look, grep {defined and -d $_}
-            map { ( "$_/rt4/lib", "$_/lib/rt4", "$_/lib" ) } @prefixes;
+            map { ( "$_/rt5/lib", "$_/lib/rt5", "$_/rt4/lib", "$_/lib/rt4", "$_/lib" ) } @prefixes;
         last if eval {local @INC = @look; require RT; $RT::LocalLibPath};
 
         warn
@@ -413,14 +413,14 @@ Path to the RT installation that contains a valid F<lib/RT.pm>.
 
 To install an extension which makes use of this installer:
 
-    perl Makefile.PL RTHOME=/opt/rt4
+    perl Makefile.PL RTHOME=/opt/rt5
 
 This will install all subdirs into the $RT::LocalPluginPath dir
 as configured in RT::Generated.
 
 To install an extension into the (vendor) plugin path:
 
-    perl Makefile.PL RTHOME=/opt/rt4 INSTALLDIRS=vendor
+    perl Makefile.PL RTHOME=/opt/rt5 INSTALLDIRS=vendor
 
 This will install all subdirs into the $RT::PluginPath which is specifically
 meant for plugins that are installed through other packaging utils like
@@ -441,7 +441,7 @@ Best Practical Solutions
 =head1 COPYRIGHT
 
 Copyright 2003, 2004, 2007 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
-Copyright 2008-2014 Best Practical Solutions
+Copyright 2008-2020 Best Practical Solutions
 
 This software is released under the MIT license cited below.
 
